@@ -188,6 +188,10 @@ def elcm_request(irmc_info, method, path, **kwargs):
           'irmc_port': 80 or 443, default is 443,
           'irmc_auth_method': 'basic' or 'digest', default is 'basic',
           'irmc_client_timeout': timeout, default is 60,
+          'irmc_verify_ca': Either a boolean, in which case it controls
+                            whether we verify the server's TLS certificate,
+                            or a string, in which case it must be a path to
+                            a CA bundle to use. Defaults to ``False``.
           ...
         }
     :param method: request method such as 'GET', 'POST'
@@ -203,6 +207,7 @@ def elcm_request(irmc_info, method, path, **kwargs):
     userid = irmc_info['irmc_username']
     password = irmc_info['irmc_password']
     client_timeout = irmc_info.get('irmc_client_timeout', 60)
+    verify = irmc_info.get('irmc_verify_ca', False)
 
     # Request headers, params, and data
     headers = kwargs.get('headers', {'Accept': 'application/json'})
@@ -229,7 +234,7 @@ def elcm_request(irmc_info, method, path, **kwargs):
                              headers=headers,
                              params=params,
                              data=data,
-                             verify=False,
+                             verify=verify,
                              timeout=client_timeout,
                              allow_redirects=False,
                              auth=auth_obj)
