@@ -223,7 +223,7 @@ class SCCITestCase(testtools.TestCase):
             'https://' + self.irmc_address + '/config',
             data=scci.POWER_ON,
             headers={'Content-type': 'application/x-www-form-urlencoded'},
-            verify=True,
+            verify=False,
             timeout=self.irmc_client_timeout,
             allow_redirects=False,
             auth=mock_requests.auth.HTTPBasicAuth(self.irmc_username,
